@@ -4,8 +4,6 @@ import os
 from .storage import *
 from .model_cache_class import ModelCacheClass
 
-valid_storage_types = ("memory", "sqlite", "redis")
-
 class ModelCache():
     @classmethod
     def connect(cls, original_model, **kwargs):
@@ -26,7 +24,7 @@ class ModelCache():
                 default_kwargs[k1] = v1
 
         # validate storage
-        assert default_kwargs['storage_type'] in valid_storage_types
+        assert default_kwargs['storage_type'] in valid_storages
         if (default_kwargs['cache_dir'] is None) and (default_kwargs['storage_type'] != "memory"):
             raise Exception(u"`cache_dir` should not be None when storage_type is not memory.")
 
